Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

172 documents were found matching the selected criteria.
Page: [ 1] 2 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Hitchcock | 2014-L-046 | APPELLATE REVIEW - post-conviction appeal is civil; Civ.R. 58(B); App.R. 4(A); thirty-day rule; untimely appeal. | Grendell | 7/28/2014 | 2014-Ohio-3281
Barreca v. Travco Behavioral Health, Inc. | 2013-T-0116 | EMPLOYMENT RELATIONS - Disability discrimination claim; elements; "disability" defined; R.C. 4112.01(A)(13); physical impairment; substantial limitation of major life activity; multiple sclerosis; summary judgment exercise. | Wright | 7/28/2014 | 2014-Ohio-3280
Beal Bank S.S.B. v. Elzy | 2013-T-0095 | CIVIL - standing; jurisdictional; holder of an instrument. | Cannon | 7/28/2014 | 2014-Ohio-3279
Sassya v. Morgan | 2013-T-0084 | DOMESTIC RELATIONS - GENERAL - summary judgment; dissolutions and separation agreements; R.C. 3105.63(A)(1); contract; distribution of property; no jurisdiction to modify agreement's terms; dissolution decree vacated; matter converted to a contested divorce action; division of marital property; R.C. 3105.171(F); custody; child support. | O'Toole | 7/28/2014 | 2014-Ohio-3278
Davison v. Parker | 2013-L-098 | CIVIL - compensatory damages; market value; motion for summary judgment; animals; personal property; R.C. 955.03. | Cannon | 7/28/2014 | 2014-Ohio-3277
State v. Cebula | 2013-L-085 | CRIMINAL LAW - intervention in lieu of conviction; hearing; required hearing upon consideration of ILC; waiver; guilty plea does not waive ILC claims; App.R. 16(A)(7). | Wright | 7/28/2014 | 2014-Ohio-3276
In re M.S. | 2014-L-036 | JUVENILE - permanent custody; termination of parental rights; R.C. 2151.413; clear and convincing evidence; R.C. 2151.414; sufficiency and weight of the evidence; ethical duties of family therapists; Ohio Adm.Code 4757-6-01(F); interaction and interrelationship between parent and child; R.C. 2151.414(D); best interests of the child | Grendell | 7/21/2014 | 2014-Ohio-3184
Madison Route 20, L.L.C. v. Lake Cty. Bd. of Revision | 2013-L-019 | TAX - valuation of real property; wetlands; real property is not worthless; issues of law de novo; board of tax appeals has discretion in determining credibility and weight of evidence; when record shows auditor's valuation is inaccurate, board of tax appeals should order more evidence. | Cannon | 7/21/2014 | 2014-Ohio-3183
Capital One Bank v. Beaver | 2014-P-0025 | APPELLATE REVIEW - Motion to reconsider from final order is nullity; lack of a final appealable order; App.R. 4(A); thirty-day rule; untimely appeal. | Grendell | 7/14/2014 | 2014-Ohio-3077
Arndt v. P&M Ltd. | 2013-P-0027 | CIVIL - breach of statutory duty; fraudulent concealment; juror voir dire; interrogatories; Civ.R. 49(B); partial summary judgment; directed verdict; Civ.R. 50(A)(4); manufactured park home operator; R.C. 4781.38(A)(2) and (3); rebuttal evidence; judgment notwithstanding the verdict; Civ.R. 50(B); motion for new trial; Civ.R. 59(A)(6); sufficient evidence; manifest weight of the evidence; recurring flooding; standard of care; reasonable diligence; Adm.Code 3701-27-07(A); motion for separate trial; Civ.R. 42(B); motion for mistrial; Civ.R. 59(A)(2); juror misconduct; frivolous conduct; R.C. 2323.51(A) and (B) | Grendell | 7/14/2014 | 2014-Ohio-3076
Zoldan v. Lordstown | 2014-T-0002 | APPELLATE REVIEW - Civ.R. 54(B); claims still pending; no just reason for delay language in appealed entry. | Rice | 7/7/2014 | 2014-Ohio-3007
State v. Aziz-Hakim | 2014-P-0011 | APPELLATE REVIEW - denial of motion to dismiss is not a final appealable until after a sentence has been rendered. | O'Toole | 7/7/2014 | 2014-Ohio-3006
State ex rel. Baker Living Trust v. Lordstown | 2013-T-0068 | APPELLATE REVIEW - issue of damages remains pending in the trial court; no final appealable order; lack of jurisdiction. | Wright | 7/7/2014 | 2014-Ohio-3005
State v. Rachel | 2013-T-0123 | CRIMINAL - doctrine of merger; R.C. 2941.25; allied offenses; res judicata; ineffective assistance of counsel; evidence de hors the record. | Cannon | 6/30/2014 | 2014-Ohio-2891
Hinton v. Masek | 2013-T-0110 | CIVIL - summary judgment; legal malpractice; representation; age discrimination claim; removed to federal court; settlement negotiations; authority to settle; withdraw; no expert opinion; no obvious breach of duty; no genuine issue of material fact; entitled to judgment as a matter of law. | Rice | 6/30/2014 | 2014-Ohio-2890
State v. Plevyak | 2013-T-0051 | CRIMINAL LAW - EVIDENCE - gross sexual imposition; Evid.R. 404(B) requires the state to provide notice if it intends to introduce evidence of other acts at trial; evidence of other acts may be introduced if the other acts were inextricably related to the crime charged; State v. Williams, 134 Ohio St.3d 521, 2012-Ohio-5695 applied; manifest weight of the evidence. | O'Toole | 6/30/2014 | 2014-Ohio-2889
Harris v. MC Sign Co. | 2013-L-115 | CIVIL - motion for sanctions; Civ.R. 37(D); Civ.R. 41 notice of voluntary dismissal; collateral issues not related to merits of the action; failure to appear at scheduled deposition; abuse of discretion; thwart the judicial process. | Cannon | 6/30/2014 | 2014-Ohio-2888
Latina v. Ciora | 2013-L-112 | CIVIL - transcript of trial court proceedings; failure to provide transcript; objections to magistrate's decision. | Cannon | 6/30/2014 | 2014-Ohio-2887
CitiMortgage, inc. v. Hijjawi | 2013-L-105 | CIVIL - summary judgment; foreclosure action; affiant's personal knowledge; standing; jurisdictional requirement; holder of an instrument. | Cannon | 6/30/2014 | 2014-Ohio-2886
Motorists Mut. Ins. Co. v. Cianfaglione | 2013-L-078; 2013-L-079 | CIVIL - declaratory judgment; general liability insurance; presumption of coverage; "conduct of your business"; who is an insured; weight of the evidence | Grendell | 6/30/2014 | 2014-Ohio-2885
State v. Cornelison | 2013-L-064 | CRIMINAL LAW - felony sentence; R.C. 2929.12 factors; consecutive sentences; R.C. 2929.14(C)(4) findings; court costs; R.C. 2947.23(A)(1)(a); error; judgment modified and affirmed as modified; ineffective assistance of counsel; no prejudice; restitution; no abuse of discretion. | Rice | 6/30/2014 | 2014-Ohio-2884
State v. McFarland | 2013-L-061 | CRIMINAL - delayed appeal; sexual battery; R.C. 2907.03; joint sentencing recommendation; R.C. 2953.08; purposes of felony sentencing; mandatory sentencing provisions; R.C. 2929.11; R.C. 2929.12. | Cannon | 6/30/2014 | 2014-Ohio-2883
State v. Weimer | 2013-L-005 | CRIMINAL LAW - Confrontation Clause; hearsay; Evid.R. 801; conspiracy; co-conspirator's statements; aggravated burglary; aggravated murder; complicity; new trial warranted; sufficiency; engaging in a pattern of corrupt activity; insufficient evidence under RICO conviction. | O'Toole | 6/30/2014 | 2014-Ohio-2882
Douglass v. Priddy | 2013-G-3172 | CIVIL - attorney disqualification; prior representation; appealable order; Prof.Cond.R. 1.0; Prof.Cond.R. 1.9; substantially related. | Cannon | 6/30/2014 | 2014-Ohio-2881
State v. Harrison | 2013-G-3168 | CRIMINAL - R.C. 2929.12; review of felony sentence; R.C. 2929.11; R.C. 2929.14; consecutive sentences. | Cannon | 6/30/2014 | 2014-Ohio-2880
Spring v. Wick | 2013-G-3163 | CIV.R. 53 - Civ.R. 11 does not require that unsigned pleading be stricken unless they are sham or false; moot; Civ.R. 53(D)(5); alleged violations of the Code of Judicial Conduct do not create substantive rights in litigants; the purpose of requiring magistrates to file findings of fact and conclusions of law under Civ.R. 53(D)(3)(a)(ii) is to allow parties to draft appropriate objections and the trial court to evaluate those objections. | O'Toole | 6/30/2014 | 2014-Ohio-2879
State v. Brown | 2013-A-0065 | CRIMINAL LAW - conspiracy to commit aggravated murder; manifest weight of the evidence; sentencing; R.C. 2929.11; R.C. 2929.12. INEFFECTIVE ASSISTANCE OF COUNSEL. | O'Toole | 6/30/2014 | 2014-Ohio-2878
State v. Beckwith | 2013-A-0050 | ASSAULT - felonious assault; appellant punches victim in bar striking him in mouth and fracturing his jaw; assault captured on videotape; video shows appellant confronting and striking victim without any provocation on part of victim; prosecutorial misconduct; appellant fails to object; plain error; evidence of appellant's guilt overwhelming; manifest weight; jury entitled to determine credibility of conflicting versions of events. | Rice | 6/30/2014 | 2014-Ohio-2877
Burdick v. Burdick | 2013-A-0030 | DOMESTIC - divorce; antenuptial agreement; separate property; R.C. 3105.171; manifest weight; de facto end date; equitable division. | Cannon | 6/30/2014 | 2014-Ohio-2876
Jack F. Neff Sand & Gravel, Inc. v. Great Lakes Crushing, Ltd. | 2012-L-145 | CIVIL - EVIDENCE - hearsay ruling reviewed de novo; Evid.R. 801(D)(2)(d) not limited to living agents of a party; limited admissibility of out-of-court statements. CONTRACTS - option to renew upon written notice not a "no oral modifications" clause; ambiguous language interpreted against the drafter; breach of contract; conversion; prior course of dealings. CORPORATIONS - piercing the corporate veil; corporate officer personally liable for own tortious acts. PREJUDGMENT INTEREST - R.C. 1343.03(A) limited to contracts that provide for payment of money by the breaching party; R.C. 1343.03(C); good faith effort to settle. JURY INSTRUCTIONS - punitive damages instruction; malice; abuse of discretion review. | Cannon | 6/30/2014 | 2014-Ohio-2875
Osborne v. Malkamaki | 2012-L-134 | DOMESTIC RELATIONS - PROPERTY - donative intent; a spouse may convert his or her separate property into marital property by an inter vivos gift to the other spouse during the course of the marriage; when the record contains little direct evidence on donative intent the issue is analyzed under the totality of the circumstances. | O'Toole | 6/30/2014 | 2014-Ohio-2874
State v. Baker | 2013-A-0020 | CRIMINAL - motion to suppress; blood test; substantial compliance; Ohio Adm. Code 3701-53-05; requirement that blood samples be refrigerated when not in transit or under examination; expert testimony; reliability of the blood sample; lack of refrigeration. | Cannon | 6/30/2014 | 2014-Ohio-2873
State v. Court | 2013-T-0122 | APPELLATE REVIEW - App.R. 4(A); untimely appeal; forfeiture proceedings; final, appealable order; non-mandatory forfeiture is civil penalty; civil proceeding; R.C. 2981.04(B); motion for delayed appeal inapplicable to civil appeals. | Grendell | 6/23/2014 | 2014-Ohio-2712
Bank of New York Mellon v. Veccia | 2013-T-0101 | REAL PROPERTY - foreclosure; mortgagee-bank held note when complaint was filed where: (1) note was previously endorsed in blank and, according to affidavit of bank's representative, as of the date complaint was filed, bank held note; and (2) the mortgage assignment, executed before complaint was filed, also assigned note to bank; bank proves it held "original" note when bank's representative states in affidavit that bank held the note without qualifying it as a copy; there was no break in chain of title of note where nominee of lender's successor assigned note to bank; bank was not required to show lender's successor had previously assigned note to successor's nominee for nominee to assign note to bank. | Rice | 6/23/2014 | 2014-Ohio-2711
State v. Alexander | 2013-T-0100 | CRIMINAL LAW - motion to vacate void judgment; sentence. RES JUDICATA. | O'Toole | 6/23/2014 | 2014-Ohio-2710
Nickles v. Spisak | 2013-P-0094 | PROBATE - summary judgment; undue influence; party contesting a will or trust has burden of proving undue influence; Evid.R 804(B)(5) can only be used to rebut testimony of a party adverse to a decedent's representative; power of attorney; when a fiduciary relationship exists between the creator of a joint and survivorship account and a surviving beneficiary a presumption of undue influence arises; no contest clauses are valid. | O'Toole | 6/23/2014 | 2014-Ohio-2709
State v. Coleman | 2013-P-0072 | CRIMINAL LAW - sufficiency of evidence; manifest weight of evidence; robbery; prosecutorial misconduct. | Cannon | 6/23/2014 | 2014-Ohio-2708
State v. Raia | 2013-P-0020 | CRIMINAL LAW - R.C. 2907.09(A)(1); exposing private parts; indecent exposure; trial judge signature; admission of prior conviction; admission to prior conviction; prove prior conviction via admission; harmless error; confrontation clause; right to confront witnesses; cross-examination; limitations on cross examination; prior inconsistent statement; impeach; impeachment; waiver: Crim.R. 12(H); Crim.R. 12(C); bias; harmless beyond a reasonable doubt. | Wright | 6/23/2014 | 2014-Ohio-2707
JPMorgan Chase Bank, Natl. Assn. v. Rhodes | 2013-L-117 | CIVIL - foreclosure; Civ.R. 60(B); no just reason for delay; prohibited indirect appeal; untimely; no meritorious defense or claim to raise. | Cannon | 6/23/2014 | 2014-Ohio-2706
State v. Rose | 2013-L-107 | APPELLATE REVIEW - App.R. 5(A); delayed appeal; reason does not justify delay; no notice of appeal filed. | Wright | 6/23/2014 | 2014-Ohio-2705
Naylor Family Partnership v. Home S. & L. Co. of Youngstown | 2013-L-096 | CIVIL - arbitration agreement; request for an accounting; R.C. 2711.02; waiver; abuse of discretion. | Cannon | 6/23/2014 | 2014-Ohio-2704
State v. Jarrells | 2013-L-090 | CRIMINAL LAW - OVI; eight-year sentence; H.B. 86; R.C. 2929.11; R.C. 2929.12; R.C. 2929.14(A)(3); R.C. 2941.1413. | O'Toole | 6/23/2014 | 2014-Ohio-2703
DiBlasi v. First Seventh-Day Adventist Community Church | 2013-G-3169 | NEGLIGENCE - negligent construction of footbridge causes it to be removed from its foundation and to block culvert causing rainwater to back up and to flood appellants' properties; on summary judgment trial court cannot reject one expert opinion for another because it believes the theory of one expert over that of another expert; for purposes of summary judgment motion, expert opinions are to be accepted as true; conflicting expert reports regarding appellees' liability raise genuine issue of material fact, precluding summary judgment. | Rice | 6/23/2014 | 2014-Ohio-2702
In re Estate of Folk | 2013-G-3266 | PROBATE - executor; removal; no opportunity to be heard; under oath; R.C. 2109.24; notice provision; R.C. 2113.18(A); no notice required; unsettled claims; subject of controversy between executor and estate or other interested party. | Rice | 6/23/2014 | 2014-Ohio-2701
Dardy v. Thompson | 2013-G-3157 | CIVIL - summary judgment; residential property lease; fire; inconclusive cause; res ipsa loquitur; negligence per se; spoliation; R.C. 5321.04; proximate cause; lack of causal connection. | Cannon | 6/23/2014 | 2014-Ohio-2700
State v. Stone | 2013-G-3154 | CRIMINAL LAW - SENTENCING/FINES, RESTITUTION, EXPUNGEMENT - attempted rape; R.C. 2923.02(A); R.C. 2907.02(A)(1)(b); gross sexual imposition; R.C. 2907.02(A)(4); R.C. 2953.08(G)(2); consecutive sentences; R.C. 2929.14(C)(4). | O'Toole | 6/23/2014 | 2014-Ohio-2699
State v. Wolf | 2013-G-3152 | CRIMINAL LAW - R.C. 4511.31; sufficiency of the evidence; manifest weight of the evidence; crossing the center line; interference with the safe operation of traffic being overtaken. | Cannon | 6/23/2014 | 2014-Ohio-2698
State v. Kuscsik | 2013-A-0058 | DRUG OFFENSES - illegal manufacture of methamphetamine; illegal assembly or possession of chemicals for manufacture of meth; sufficient evidence to support appellant's conviction as principal or aider or abettor was presented where officer detected strong odor of meth in appellant's house, especially near his bedroom; appellant's longtime friend, with whom appellant admitted he has used drugs and who appellant admitted brought two meth labs with him that night, was found by police in appellant's bedroom manufacturing meth; appellant's friend told police he came to appellants house that night to buy drugs; materials used in production and use of meth were found in appellant's bedroom; and meth was found on several of those items. | Rice | 6/23/2014 | 2014-Ohio-2697
Nappi v. Nappi | 2013-A-0041 | DOMESTIC - qualified domestic relations order; frozen coverture method; traditional coverture method. | Per Curiam | 6/23/2014 | 2014-Ohio-2696
State v. Spears | 2013-A-0027 | CRIMINAL - Anders; receiving stolen property; Crim.R. 11; guilty plea; substantial compliance; ineffective assistance of counsel; R.C. 2929.11. | Cannon | 6/23/2014 | 2014-Ohio-2695
State v. Bowers | 2014-T-0025 | APPELLATE REVIEW - App.R. 5(A); delayed appeal; no notice of appeal filed. | Cannon | 6/16/2014 | 2014-Ohio-2568
State v. Elder | 2013-L-128 | CRIMINAL - motion for a new trial; Crim.R. 5(B)(7); preliminary hearing; uniform traffic citation; indictment; Traf.R. 2(A); lack of prejudice; Crim.R. 11(A); entry of not guilty plea; structural error; failure to assert a sufficiently specific assignment of error | Grendell | 6/16/2014 | 2014-Ohio-2567
State v. Thompson | 2013-A-0033 | CRIMINAL LAW - SEARCH & SEIZURE - where appellant crossed fog line three times and followed a vehicle too closely in violation of Revised Code, trooper had probable cause to stop him; where multiple Evans factors are present and trooper had experience in dealing with drunk drivers, he had sufficient grounds to ask appellant to submit to field sobriety tests; where appellant generally argued in his motion to suppress that state failed to administer field sobriety tests in substantial compliance with applicable standards without specifying which standards were violated, trooper's general testimony that his test procedures complied with standard procedures overcame motion to suppress; where trooper followed procedures adopted by NHTSA in administering field sobriety tests, although he did not expressly testify to such, he administered them in substantial compliance with those standards. | Rice | 6/16/2014 | 2014-Ohio-2566
Hylbert v. WEB Bldg. & Dev., Inc. | 2013-P-0095 | CIVIL - summary judgment; implied-in-fact contract; promissory estoppel; de novo review; Civ.R. 56; representative capacity. | Cannon | 6/9/2014 | 2014-Ohio-2456
State v. Householder | 2013-P-0092 | CRIMINAL - felony sentencing; consecutive sentences; R.C. 2929(C)(4); statutory findings; Crim.R. 32(A)(4) | Grendell | 6/9/2014 | 2014-Ohio-2455
Cireddu v. Clough | 2013-L-092 | DOMESTIC RELATIONS - visitation; abuse of discretion; discovery; production of documents; child support modification; verification of income; variable income; Civ.R 53(D)(4)(d); additional evidence; child support deviation; equal parenting time; tax exemption designation; modification of visitation; best interest of the child; R.C. 3109.051 | Grendell | 6/9/2014 | 2014-Ohio-2454
State v. Goldberg | 2013-A-0063 | CRIMINAL LAW - Sufficiency of the evidence; territorial jurisdiction; municipal court; R.C. 1901.02(A); R.C. 1901.01(A); location where crime was committed; manifest weight of the evidence; circumstantial evidence; criminal damaging; use of car key to scratch paint on another vehicle. | WRIGHT | 6/9/2014 | 2014-Ohio-2453
Tuli v. Tuli | 2013-T-0092 | DOMESTIC RELATIONS - Civ.R. 60(B) motion; abuse of discretion; meritorious defense; grounds for relief; newly discovered evidence; Civ. R. 60(B)(5); reservation of right to file 60(B) motion. | Grendell | 6/2/2014 | 2014-Ohio-2330
State v. Porterfield | 2014-T-0005 | VEXATIOUS LITIGATOR - R.C. 2323.52(G); denial of request for leave at trial level to file new motion; non-appealable judgment. | Wright | 5/27/2014 | 2014-Ohio-2225
State v. Lewis | 2013-L-111 | CRIMINAL LAW - Alleyne; Apprendi; post-conviction; retroactive; retroactivity; timeliness. | Wright | 5/27/2014 | 2014-Ohio-2224
King v. King | 2013-G-3155 | DOMESTIC RELATIONS - Enforcement of separation agreement; appointment of receiver to sell marital residence; failure of wife to refinance loan so that husband is no longer liable; execution of quitclaim deed has no effect upon liability; issue previously litigated; res judicata; improper use of Civ.R. 60(B). | Wright | 5/27/2014 | 2014-Ohio-2223
State v. Smith | 2013-A-0061 | CRIMINAL LAW - right to court-appointed counsel; right to jury trial; discovery; speeding; R.C. 4511.21(D)(2); reckless operation of a motor vehicle; R.C. 4511.20; prior conviction; Crim.R. 44; no court-appointed counsel results in inability to impose prison term; petty offense; minor misdemeanor; prosecutorial discretion in charging; Crim.R. 12(H); waiver of pre-trial criminal issues. | Cannon | 5/19/2014 | 2014-Ohio-2115
State v. Johnson | 2013-T-0121 | APPELLATE REVIEW - App.R. 5(A); delayed appeal; reason does not justify delay; Loc.R. 3(D)(3). | Cannon | 5/12/2014 | 2014-Ohio-2015
State v. Wilson | 2013-L-075 | CRIMINAL - Grand Theft; involuntary plea; error in transcript; App.R. 9(E) correction of the record | Grendell | 5/12/2014 | 2014-Ohio-2014
Kolleda v. Kolleda | 2013-L-069 | parental rights; change of custody; R.C. 3109.04(E)(1)(a)(iii); change in circumstances; best interests; contempt | Grendell | 5/12/2014 | 2014-Ohio-2013
State v. Demeo | 2013-A-0067 | CRIMINAL LAW - SENTENCING/FINES, RESTITUTION, EXPUNGEMENT - grand theft; R.C. 2929.11; R.C. 2929.12; consecutive sentences are reviewed under R.C. 2953.08(G)(2); R.C. 2929.14(C)(4); maximum sentence. | O'Toole | 5/12/2014 | 2014-Ohio-2012
Mentor v. Meyers | 2012-L-141 | CRIMINAL - pro se defendant; minor misdemeanor; disorderly conduct; right to court-appointed trial counsel; right to jury trial; Crim.R. 16; motion to compel discovery; right to confrontation; right to present favorable witnesses; Sixth Amendment; First Amendment; protected speech; fighting words; right to court-appointed appellate counsel; loss of liberty; contempt; right to trial transcripts; App.R. 9; debtor's prison. | Cannon | 5/12/2014 | 2014-Ohio-2011
State v. Lane | 2013-G-3144 | STATUTES - CONSTITUTION - Ohio's mandatory juvenile bindover statutes, R.C. 2152.10 and R.C. 2152.12, do no not violate due process, equal protection, or prohibition against cruel and unusual punishment. CRIMINAL LAW - SENTENCING/FINES, RESTITUTION, EXPUNGEMENT - juvenile homicide offender's discretionary life without parole sentence is not cruel and unusual punishment where trial court considered offender's youth as a mitigating factor; Miller v. Alabama; State v. Long; ineffective assistance of counsel; consecutive sentences are not contrary to law when trial court makes required findings under R.C. 2929.14(C).. | Rice | 5/12/2014 | 2014-Ohio-2010
State v. Johnson | 2014-G-3200 | APPELLATE REVIEW- Final appealable order; criminal proceeding; lack of sentencing order; finding of guilt insufficient. | Wright | 5/5/2014 | 2014-Ohio-1875
State v. Warner | 2013-P-0056 | CRIMINAL LAW - SEARCH & SEIZURE - where police officer lawfully stops defendant in vehicle and defendant then parks and flees on foot defendant voluntarily abandons vehicle and cannot challenge search of its contents; where trial court did not address abandonment there is no need to remand for court to rule on this issue where evidence could only result in finding that defendant voluntarily abandoned vehicle. | Rice | 5/5/2014 | 2014-Ohio-1874
Kilroy v. Sheridan | 2013-P-0052 | APPELLATE REVIEW - R.C. 2505.02(B); final appealable order; declaratory judgment action; failure to analyze disputed language in written easement and delineate rights and responsibilities of the parties; mere granting of summary judgment insufficient to issue final order. | Wright | 5/5/2014 | 2014-Ohio-1873
Stewart v. Tabitha ("E") | 2013-P-0009 | CIVIL PROCEDURE - Civ.R. 60(B); motion for relief from judgment; motion for relief of judgment cannot substitute a direct appeal; App.R. 4; untimely, one year window Civ.R. 60(B)(3). | Wright | 5/5/2014 | 2014-Ohio-1872
Swartz v. Formica Plumbing & Sewer Co. | 2013-L-134 | APPELLATE REVIEW - lack of a final appealable order; Civ.R. 54(B); multiple claims or parties; counterclaims; no just reason for delay | Grendell | 5/5/2014 | 2014-Ohio-1871
State v. Moore | 2013-L-052 | POST CONVICTION RELIEF - R.C. 2953.23(A)(1); successive petitions for postconviction relief; Lafler v. Cooper, __U.S. __, 132 S.Ct. 1376 (2012) and Missouri v. Frye, __U.S. __, 132 S.Ct. 1399 (2012) did not recognize any new constitutional right; R.C. 2929.14(B)(1)(g); if a defendant is found guilty of two counts of aggravated robbery, each including a firearm specification pursuant to R.C. 2941.145. the trial court cannot merge the firearm specifications for sentencing purposes. | O'Toole | 5/5/2014 | 2014-Ohio-1870
Rhoades v. Rhoades | 2013-A-0051 | DOMESTIC RELATIONS - GENERAL - R.C. 3105.171(C)(1); an equal division of marital property is not required if an equal division is inequitable; a trial court's division of marital property is reviewed for abuse of discretion; R.C. 3105.171(A)(2)(a); the date for determining the value of marital property is generally the date of final hearing; spousal support; R.C. 3105.18(B); R.C. 3105.18(C)(1). | O'Toole | 5/5/2014 | 2014-Ohio-1869
Garcia v. Gillette | 2013-A-0015 | REAL PROPERTY - a trial court's determination of damages is reviewed for abuse of discretion; R.C. 713.13; trial courts are not required to grant injunctive relief to cure nuisances under R.C. 713.13 when such relief would be excessively burdensome; the grant or denial of attorney fees in a case for trespass is within the discretion of the trier of facts; when property values can be ascertained with certainty approximations of value are disfavored. | O'Toole | 5/5/2014 | 2014-Ohio-1868
State v. Johnson | 2014-G-3187 | APPELLATE REVIEW-CRIMINAL - denial of motion to suppress and for change of venue are not final appealable orders until sentence is rendered. | Wright | 4/28/2014 | 2014-Ohio-1781
Aquasea Group, L.L.C. v. Singletary | 2013-T-0120 | APPELLATE REVIEW - lack of a final appealable order; R.C. 2505.02(B)(4); preliminary injunction; permanent injunction; status quo; calculable monetary losses | Grendell | 4/28/2014 | 2014-Ohio-1780
Meadows v. Trumbull Cty. Health Dept. | 2013-T-0105 | APPELLATE REVIEW - lack of a final appealable order; multiple claims or parties; Civ.R. 54(B); no just reason for delay. | Grendell | 4/28/2014 | 2014-Ohio-1779
State v. Williams | 2013-T-0070 | CRIMINAL LAW - Criminal conviction for felonious assault; manifest weight of the evidence; witness credibility; existence of conflicting testimony as to non-element issue; factfinder can believe all, part, or none of a witness's testimony. | Wright | 4/28/2014 | 2014-Ohio-1778
Avakian v. Avakian | 2013-P-0081 | APPELLATE REVIEW - Contempt of court has two elements; finding of contempt and imposition of penalty or sanction; no final order until both are met. | Rice | 4/28/2014 | 2014-Ohio-1777
Novy v. Ferrera | 2013-P-0063 | CIVIL - Trespass; Nuisance; Intentional Interference with the Flow of Water; summary judgment; negligence, reasonable-use rule; duplicative claims; manifest weight of the evidence; nominal damages required in trespass case; punitive damages; permanent injunction; abuse of discretion; irreparable injury; public interest; admission of evidence; Evid.R. 703; failure to disclose witness | Grendell | 4/28/2014 | 2014-Ohio-1776
State v. Lynch | 2013-A-0039 | CRIMINAL LAW - illegal manufacture of methamphetamine; illegal assembly or possession of chemicals for the manufacture of drugs; speedy trial; motion to dismiss; ineffective assistance of counsel; manifest weight, sufficient weight; statutory right to speedy trial; triple county provision; pending on one charge. | Wright | 4/28/2014 | 2014-Ohio-1775
State v. Jarvi | 2013-A-0037 | CRIMINAL LAW - Sentencing; R.C. 2929.12; factors relating to seriousness of offense and recidivism; no duty for trial court to discuss factors on record; presumption of consideration; appellate standard for review of felony sentence; adherence to applicable law; abuse of discretion; seriousness of offense entitled to greater weight under circumstances. | Wright | 4/28/2014 | 2014-Ohio-1774
State v. Finch | 2013-P-0046 | SENTENCING - photographing a nude minor, R.C. 2907.323; mental illness; Kalish; felony sentencing; second degree felony; consideration of R.C. 2929.12; presume consideration of R.C. 2929.12 factors from silent record. | Wright | 4/21/2014 | 2014-Ohio-1680
State v. Reyes | 2013-P-0049 | CRIMINAL PROCEDURE - Guilty plea; motion to withdraw plea; Crim.R. 32.1; post-judgment standard; manifest injustice; need for evidentiary hearing; joint sentencing recommendation; not binding upon trial court; no breach of promise by state. | Wright | 4/21/2014 | 2014-Ohio-1679
Mundy v. Mundy | 2013-P-0102 | APPELLATE REVIEW - lack of a final, appealable order; multiple claims or parties; Civ.R. 54(B); no just reason for delay. | Cannon | 4/21/2014 | 2014-Ohio-1678
In re D.A. | 2013-T-0059 | JUVENILE - Finding of delinquency based upon sex offense; two-step process for deciding if juvenile should be classified as a juvenile sex offender; juvenile offender registrant; discretionary determination under certain circumstances; R.C. 2152.83(B)(1); failure of trial court to exercise discretion and consider statutory factors; meaningful opportunity to address factors during hearing; timing of decision to classify juvenile as a sex offender; discretion of trial court under R.C. 2152.83(B). | Wright | 4/21/2014 | 2014-Ohio-1677
State v. Floyd | 2013-T-0097 | APPELLATE REVIEW - App.R. 5(A); delayed appeal; reason does not justify delay. | Grendell | 4/21/2014 | 2014-Ohio-1676
State v. Sanders | 2013-P-0087 | CRIMINAL PROCEDURE - Crim.R. 32(C); requirements for valid final sentencing judgment; statement of "fact" of conviction; statement of acceptance of guilty plea not mandatory; de novo sentencing hearing not required when case is remanded for proper notification of post-release control. | Wright | 4/14/2014 | 2014-Ohio-1573
Career & Technical Assn. v. Auburn Vocational School Dist. Bd. of Edn. | 2013-L-010 | CONTRACTS - interpretation of contract requires ambiguity; collective bargaining agreement; provision requiring extra payment for teacher where no planning period is provided; where provision is ambiguous question of fact exists as to parties' intent; where contract term is ambiguous court must consider parol evidence; title of contract provision is generally considered in determining meaning of provision; technical | Rice | 4/14/2014 | 2014-Ohio-1572
Wolkoff v. Bloom Bros. Supply, Inc. | 2013-G-3160 | CIVIL - notice of appeal; App.R. 4(A); appellate jurisdiction; App.R. 3(A); magistrate decisions; objections; transcript; Civ.R. 53(D)(3)(b)(iii) | Grendell | 4/14/2014 | 2014-Ohio-1567
State v. Gray | 2014-T-0008 | APPELLATE REVIEW - App.R. 4(A); thirty-day rule; untimely appeal. | Cannon | 4/7/2014 | 2014-Ohio-1476
Bank of Am. v. Kohler | 2014-P-0004 | APPELLATE REVIEW - App.R. 4(A); thirty-day rule; untimely appeal. | O'Toole | 4/7/2014 | 2014-Ohio-1475
In re Adoption of J.A.B. | 2013-T-0114 | PROBATE - petition for placement for adoption; termination of parental rights; incarcerated father's right to consent; R.C. 5103.16(D)(3); R.C. 3107.07(A); justifiable cause; support. | O'Toole | 3/31/2014 | 2014-Ohio-1375
State ex rel. Huntington Natl. Bank v. Kontos | 2013-T-0089 | EXTRAORDINARY WRITS - procedendo; prohibition; an adequate legal remedy does exist; motion to dismiss granted. | O'Toole | 3/31/2014 | 2014-Ohio-1374
Fiduciary Trust Co. v. Bigley | 2013-T-0077 | CIVIL - Civ.R. 60(B); timeliness; reasonable; abuse of discretion; failure to hold a hearing. | Cannon | 3/31/2014 | 2014-Ohio-1373
King Painting & Wallpapering, Inc. v. Aswin Ganapathy Hospitality Assocs., L.L.C. | 2013-T-0076 | OTHER CIVIL RULES - discovery; trial court's decisions regarding discovery can only be overturned on a showing of an abuse of discretion; Civ.R. 36; any matter admitted under this rule is conclusively established; if discovery requests include requests for admission, caption must indicate they include requests for admission; waiver; lack of prejudice from failure of caption to indicate discovery requests include requests for admission; when request for admission contains several assertions of fact, general denial to the request for admission amounts to an admission; Civ.R. 56; a request for admission deemed admitted is competent evidence to support motion for summary judgment. | Rice | 3/31/2014 | 2014-Ohio-1372
State v. Weaver | 2013-T-0066 | CRIMINAL LAW – CONSTITUTIONAL – constitutional arguments may be reviewed for the first time on appeal; repeat violent offender specification; special finding by the jury that defendant inflicted, attempted to inflict, or threatened to inflict serious physical harm; R.C. 2929.14(B)(2)(a)(ii) is not void for vagueness. | Cannon | 3/31/2014 | 2014-Ohio-1371
Rossi v. Rossi | 2013-T-0058 | DOMESTIC RELATIONS - division of assets; disability benefits; new trial; interpretation of judgment entry. | Wright | 3/31/2014 | 2014-Ohio-1370

Page: [ 1] 2 next